import resources
import os
from xml.dom import minidom
import xbmc

class Addon:
    """
    Addon class.
    
    Addon(id) -- Creates a new Addon class.
    id          : string - id of the addon.

    *Note, You can use the above as a keyword.
    example:
     - self.Addon = xbmcaddon.Addon(id='script.recentlyadded')
    """
    
    info = {'profile': 'special://masterprofile/'}
    settings = {}
    
    def __init__(self, id):
        """
        """
        self.addonId = id;
        settingsFile = os.path.join( xbmc.translatePath("special://masterprofile/") , 'settings.xml')
        if os.path.exists(settingsFile):
            doc = minidom.parse(settingsFile)
            nodes = doc.getElementsByTagName("setting")
            for node in nodes:
                self.settings[node.getAttribute('id')] = node.getAttribute('value')
        
    def setSetting(self, label, value):
        """
        -- Sets a script setting.       
        id        : string - id of the setting that the module needs to access.
        value     : string or unicode - value of the setting.
        *Note, You can use the above as keywords for arguments.
        example:
          - self.Settings.setSetting(id='username', value='teamxbmc')
        """
        self.settings[label] = value
        
    def getSetting(self, label):
        """
        -- Returns the value of a setting as a unicode string.
        id        : string - id of the setting that the module needs to access.
        *Note, You can use the above as a keyword.
        example:
        - apikey = self.Addon.getSetting('apikey')
        """
        return self.settings[label]
        
    def _setAddonInfo(self, label, value):
        self.info[label] = value
        
    def getAddonInfo(self, infoLabel):
        """
        -- Returns the value of an addon property as a string.\n"
    
        id        : string - id of the property that the module needs to access.
        
        *Note, choices are (author, changelog, description, disclaimer, fanart. icon, id, name, path, profile, stars, summary, type, version)
    
           You can use the above as keywords for arguments.
    
        example:
          - version = self.Addon.getAddonInfo('version')
        """
        return self.info[infoLabel]
    
    def getLocalizedString(self, id):
        """
        -- Returns an addon's localized 'unicode string'.
        id             : integer - id# for string you want to localize.
        *Note, You can use the above as keywords for arguments.
        example:
          - locstr = self.Addon.getLocalizedString(id=6)
        """
        return str(id)
        
    def openSettings(self):
        """ 
        -- Opens this scripts settings dialog.
        
        example:
          - self.Settings.openSettings()
        """
    


