ICON_OVERLAY_HAS_TRAINER = 4
ICON_OVERLAY_HD = 8
ICON_OVERLAY_LOCKED = 3
ICON_OVERLAY_NONE = 0
ICON_OVERLAY_RAR = 1
ICON_OVERLAY_TRAINED = 5
ICON_OVERLAY_UNWATCHED = 6
ICON_OVERLAY_WATCHED = 7
ICON_OVERLAY_ZIP = 2

class Dialog:
    
    yesnoAnswer = False
    
    def __init__(self):
        ""
        
    def _setyesno(self, answer):
        self.yesnoAnswer = answer
        
    def yesno(self, *messages):
        ""
        for m in messages :
            print m
        print "answer: " + str(self.yesnoAnswer)
        return self.yesnoAnswer

class DialogProgress:
    """
        DialogProgress class.
     """


    def close(self):
        """
         -- Close the progress dialog.
         
        example:
          - pDialog.close()
        """

    def create(self, heading, line1=None, line2=None, line3=None):
        """
        -- Create and show a progress dialog.
         
        heading        : string or unicode - dialog heading.
        line1          : string or unicode - line #1 text.
        line2          : [opt] string or unicode - line #2 text.
        line3          : [opt] string or unicode - line #3 text.
         
        *Note, Use update() to update lines and progressbar.
         
        example:
          - pDialog = xbmcgui.DialogProgress()
          - ret = pDialog.create('XBMC', 'Initializing script...')
        """

    def iscanceled(self):
        """
         -- Returns True if the user pressed cancel.
     
        example:
          - if (pDialog.iscanceled()): return
        """

    def update(self, percent, line1=None, line2=None, line3=None):
        """
         -- Update's the progress dialog.
        
        percent        : integer - percent complete. (0:100)
        line1          : [opt] string or unicode - line #1 text.
        line2          : [opt] string or unicode - line #2 text.
        line3          : [opt] string or unicode - line #3 text.
         
        *Note, If percent == 0, the progressbar will be hidden.
         
        example:
          - pDialog.update(25, 'Importing modules...')
        """

class ListItem:
    
    def __init__(self, label=None, label2=None, iconImage=None, thumbnailImage=None, path=None): 
        """
        -- Creates a new ListItem.
         
        label          : [opt] string or unicode - label1 text.
        label2         : [opt] string or unicode - label2 text.
        iconImage      : [opt] string - icon filename.
        thumbnailImage : [opt] string - thumbnail filename.
        path           : [opt] string or unicode - listitem's path.
         
        *Note, You can use the above as keywords for arguments and skip certain optional arguments.
               Once you use a keyword, all following arguments require the keyword.
         
        example:
          - listitem = xbmcgui.ListItem('Casino Royale', '[PG-13]', 'blank-poster.tbn', 'poster.tbn', path='f:\\movies\\casino_royale.mov')
        """

    def addContextMenuItems(self, items, replaceItems=False):
        """
         -- Adds item(s) to the context menu for media lists.
         
        items               : list - [(label, action,)*] A list of tuples consisting of label and action pairs.
            - label           : string or unicode - item's label.
            - action          : string or unicode - any built-in function to perform.
        replaceItems        : [opt] bool - True=only your items will show/False=your items will be added to context menu(Default).
         
        List of functions - http://xbmc.org/wiki/?title=List_of_Built_In_Functions 
         
        *Note, You can use the above as keywords for arguments and skip certain optional arguments.
               Once you use a keyword, all following arguments require the keyword.
         
        example:
          - listitem.addContextMenuItems([('Theater Showtimes', 'XBMC.RunScript(special://home/scripts/showtimes/default.py,Iron Man)',)])
        """


    def getLabel(self):
        """
        -- Returns the listitem label.
         
        example:
          - label = self.list.getSelectedItem().getLabel()
        """

    def getLabel2(self):
        """
        -- Returns the listitem's second label.
         
        example:
          - label2 = self.list.getSelectedItem().getLabel2()
        """

    def getProperty(self, key):
        """
        -- Returns a listitem property as a string, similar to an infolabel.
         
        key            : string - property name.
         
        *Note, Key is NOT case sensitive.
               You can use the above as keywords for arguments and skip certain optional arguments.
               Once you use a keyword, all following arguments require the keyword.
         
        example:
          - AspectRatio = self.list.getSelectedItem().getProperty('AspectRatio')
        """


    def isSelected(self):
        """
        -- Returns the listitem's selected status.
         
        example:
          - is = self.list.getSelectedItem().isSelected()
        """

    def select(self, selected): 
        """
        -- Sets the listitem's selected status.
         
        selected        : bool - True=selected/False=not selected
         
        example:
          - self.list.getSelectedItem().select(True)
        """

    def setIconImage(self, icon) :
        """
        -- Sets the listitem's icon image.
         
        icon            : string - image filename.
         
        example:
        - self.list.getSelectedItem().setIconImage('emailread.png')
        """

    def setInfo(self, type, infoLabels) :
        """
        -- Sets the listitem's infoLabels.
         
        type           : string - type of media(video/music/pictures).
        infoLabels     : dictionary - pairs of { label: value }.
         
        *Note, To set pictures exif info, prepend 'exif:' to the label. Exif values must be passed
               as strings, separate value pairs with a comma. (eg. {'exif:resolution': '720,480'}
               See CPictureInfoTag::TranslateString in PictureInfoTag.cpp for valid strings.
         
               You can use the above as keywords for arguments and skip certain optional arguments.
               Once you use a keyword, all following arguments require the keyword.
         
        General Values that apply to all types:
            count       : integer (12) - can be used to store an id for later, or for sorting purposes
            size        : long (1024) - size in bytes
            date        : string (%d.%m.%Y / 01.01.2009) - file date
         
        Video Values:
            genre       : string (Comedy)
            year        : integer (2009)
            episode     : integer (4)
            season      : integer (1)
            top250      : integer (192)
            tracknumber : integer (3)
            rating      : float (6.4) - range is 0..10
            watched     : depreciated - use playcount instead
            playcount   : integer (2) - number of times this item has been played
            overlay     : integer (2) - range is 0..8.  See GUIListItem.h for values
            cast        : list (Michal C. Hall)
            castandrole : list (Michael C. Hall|Dexter)
            director    : string (Dagur Kari)
            mpaa        : string (PG-13)
            plot        : string (Long Description)
            plotoutline : string (Short Description)
            title       : string (Big Fan)
            duration    : string (3:18)
            studio      : string (Warner Bros.)
            tagline     : string (An awesome movie) - short description of movie
            writer      : string (Robert D. Siegel)
            tvshowtitle : string (Heroes)
            premiered   : string (2005-03-04)
            status      : string (Continuing) - status of a TVshow
            code        : string (tt0110293) - IMDb code
            aired       : string (2008-12-07)
            credits     : string (Andy Kaufman) - writing credits
            lastplayed  : string (%Y-%m-%d %h:%m:%s = 2009-04-05 23:16:04)
            album       : string (The Joshua Tree)
            votes       : string (12345 votes)
            trailer     : string (/home/user/trailer.avi)
         
        Music Values:
            tracknumber : integer (8)
            duration    : integer (245) - duration in seconds
            year        : integer (1998)
            genre       : string (Rock)
            album       : string (Pulse)
            artist      : string (Muse)
            title       : string (American Pie)
            rating      : string (3) - single character between 0 and 5
            lyrics      : string (On a dark desert highway...)
         
        Picture Values:
            title       : string (In the last summer-1)
            picturepath : string (/home/username/pictures/img001.jpg)
            exif*       : string (See CPictureInfoTag::TranslateString in PictureInfoTag.cpp for valid strings)
         
        example:
          - self.list.getSelectedItem().setInfo('video', { 'Genre': 'Comedy' })
        """

    def setLabel(self, label): 
        """
        -- Sets the listitem's label.
         
        label          : string or unicode - text string.
         
        example:
        - self.list.getSelectedItem().setLabel('Casino Royale')
        """

    def setLabel2(self, label2):
        """
        -- Sets the listitem's second label.
     
        label2         : string or unicode - text string.
     
        example:
          - self.list.getSelectedItem().setLabel2('[pg-13]')
        """

    def setPath(self, path):
        """
        -- Sets the listitem's path.
         
        path           : string or unicode - path, activated when item is clicked.
         
        *Note, You can use the above as keywords for arguments.
         
        example:
        - self.list.getSelectedItem().setPath(path='ActivateWindow(Weather)')
        """

    def setProperty(self, key, value):
        """
        -- Sets a listitem property, similar to an infolabel.
         
        key            : string - property name.
        value          : string or unicode - value of property.
         
        *Note, Key is NOT case sensitive.
                You can use the above as keywords for arguments and skip certain optional arguments.
                Once you use a keyword, all following arguments require the keyword.
         
        Some of these are treated internally by XBMC, such as the 'StartOffset' property, which is
        the offset in seconds at which to start playback of an item.  Others may be used in the skin
        to add extra information, such as 'WatchedCount' for tvshow items
         
        example:
        - self.list.getSelectedItem().setProperty('AspectRatio', '1.85 : 1')
        - self.list.getSelectedItem().setProperty('StartOffset', '256.4')
        """

    def setThumbnailImage(self, thumb):
        """
        -- Sets the listitem's thumbnail image.
         
        thumb           : string - image filename.
         
        example:
          - self.list.getSelectedItem().setThumbnailImage('emailread.png')
        """
        
