import md5
import pickle
import os
import sys
import re
import urllib
import shutil
import xbmc
import xbmcgui
import xbmcaddon
import xbmcplugin
from BeautifulSoup import BeautifulSoup
from string import join
from resources.lib.utils import isCacheValid, debug, unescapeHTMLchar, downloadHTML, is_number
from pickle import HIGHEST_PROTOCOL

__addonid__ = 'plugin.video.mangastv'
__settings__ = xbmcaddon.Addon(id=__addonid__)
__site_url__ = "http://mangas-tv.com/"
__version__ = "1.0.4"

CATEGORIE_LIST_MODE = 'categorielist'
ANIME_LIST_MODE = 'animelist'
MOST_VIEWED_MODE = 'mostviewed'
PROMOTED_LIST_MODE = 'promoted'
PLAY_VIDEO_MODE = 'playVideo'
SHOW_EPISODES_MODE = 'showEpisodes' 

# Empty cache dir when we change the version
cache_dir = os.path.join(xbmc.translatePath(__settings__.getAddonInfo('profile')), "cache")
versionfile = os.path.join(cache_dir, __version__)
if not os.path.exists(cache_dir):
	os.makedirs(cache_dir)
elif not os.path.exists(versionfile) :
	shutil.rmtree(cache_dir)
	os.makedirs(cache_dir)
	f = open(versionfile, 'w')
	f.close()

class UpdateArgs:

	def __init__(self, args):
		for key, value in args.iteritems():
			if value == 'None':
				args[key] = None
			else:
				args[key] = urllib.unquote_plus(args[key])
		self.__dict__.update(args)

class UI:
	
	modeToContentDict = {CATEGORIE_LIST_MODE: 'movies',
						MOST_VIEWED_MODE : 'movies',
						PROMOTED_LIST_MODE: 'movies',
						ANIME_LIST_MODE: 'tvshows',
						SHOW_EPISODES_MODE: 'episodes',
						PLAY_VIDEO_MODE: 'episodes' }
	
	def __init__(self):
		self.main = Main(checkMode=False)
		self.pagelimit = __settings__.getSetting('page_limit')
		self.cache_delay = int(__settings__.getSetting('cache_delay'))
		if self.main.args.mode is not None:
			xbmcplugin.setContent(int(sys.argv[1]), self.modeToContentDict[self.main.args.mode])
		else:
			xbmcplugin.setContent(int(sys.argv[1]), 'files')
		
	def welcomePage(self):
		self.addItem({'Title': 'Categories', 'mode':CATEGORIE_LIST_MODE, 'url': __site_url__ + "index.php?module=listeMangas"})
		self.addItem({'Title': 'Les plus vus', 'mode': MOST_VIEWED_MODE, 'url': __site_url__ + 'index.php?module=listeMangas&voir=vus&d=1&l=' + str(self.pagelimit)})
		self.addItem({'Title': 'Promus par les utilisateurs', 'mode': PROMOTED_LIST_MODE, 'url': __site_url__ + 'index.php?module=listeMangas&voir=prom&d=1&l=' + str(self.pagelimit)})
		self.addItem({'Title': 'Tous les animes', 'mode': ANIME_LIST_MODE, 'url': __site_url__ + 'index.php?module=listeMangas&voir=tous&d=1'})
		self.endofdirectory()

	def __getFromCache(self, main, processFct, addSingleItemFct):
		listItems = []
		cachefilepath = os.path.join(cache_dir, md5.new(main.args.url).hexdigest())
		if isCacheValid(cachefilepath, max_age=3600 * self.cache_delay):
			cachefile = open(cachefilepath, 'rb')
			listItems = pickle.load(cachefile)
			total = len(listItems)
			for item in listItems:
				addSingleItemFct(item, total)	
		else:
			dialog = xbmcgui.DialogProgress()
			dialog.create("Mangas-TV.com", "Getting the full list !", "This may take some time.", "Please wait ...")
			dialog.update(50)
			htmlSource = downloadHTML(main.args.url)
			soup = BeautifulSoup(htmlSource)
			dialog.update(100)
			dialog.close()
			processFct(soup, listItems)
			cachefile = open(cachefilepath, 'wb')
			pickle.dump(listItems, cachefile, HIGHEST_PROTOCOL)
			
		self.endofdirectory(sortMethod='title')

	def showCategories(self, main):
		def __parseCategory(soup, listItems):
			listCategories = soup.find('div', attrs={'id':'vignetteCategoriesTrie'}).findAll('div', attrs={'class':'vignetteCategorie'})
			total = len(listCategories)
			for cat in listCategories:
				thumb = __site_url__ + cat.find('img')['src']
				url = __site_url__ + cat.find('a')['href'] + '&l=' + str(self.pagelimit)
				title = join(cat.findAll(text=True)).strip()
				debug("thumb = %s , href = %s, title = %s" % (thumb, url, title))
				item = {'Title': title, 'mode' : ANIME_LIST_MODE, 'url': url, 'category': title, 'Thumb' : thumb}
				listItems.append(item)
				__addSingleItem(item, total)
		
		def __addSingleItem(item, total):
			self.addItem(info=item, total_items=total)
		
		self.__getFromCache(main, __parseCategory, __addSingleItem)
			
	def showAnimeSeries(self, main):
		def __parseAnimeSeries(soup, listItems):
			listArticleManga = soup.findAll('div', attrs={'class':'articleManga'})
			total=len(listArticleManga)
			for articleManga in listArticleManga:
				title = articleManga.find("div", attrs={"class": "nomMangaFr"}).find("a").find(text=True).strip()
				url = __site_url__ + articleManga.find("div", attrs={"class": "nomMangaFr"}).find("a")['href']
				image = __site_url__ + articleManga.find('img', attrs={'class': 'articleMangaImage'})['src']
				desc = articleManga.find('p', attrs={'class': 'articleMangaDescription'}).find(text=True).strip()
				stats = articleManga.find("div", attrs={"class": "optionDetailManga"}).findAll('b')
				
				# get genre
				genreList = articleManga.find("td", attrs={"class": "articleMangaContenu"}).find('table').findAll('td')
				
				genre = ""
				prevGVotes = 0
				for genreTd in genreList:
					genreCandidate = genreTd.find("br").nextSibling.strip()
					gVotes = int(genreTd.find("b").string)	
					if prevGVotes > 0 :
						genre = genre + ', ' + genreCandidate
					else :
						genre = genreCandidate
					prevGVotes = gVotes
				
				infoLabels = { "name": title, "plot": desc, "genre": genre}
				rating, votes, views = stats[1].find(text=True),stats[2].find(text=True),stats[3].find(text=True)
				if rating is not None and is_number(rating):
					infoLabels['rating'] =  float(rating)
				else : 
					infoLabels['rating'] = 0.0
				if votes is not None and is_number(rating):
					infoLabels['votes'] =  long(votes)
				else:
					infoLabels['votes'] = 0
				if views is not None and is_number(rating):
					infoLabels['playcount'] = long(views)
				else:
					infoLabels['playcount'] = 0
				info = {'Title': title, 'mode' : SHOW_EPISODES_MODE, 'url': url , 'Thumb' : image}
				debug('info = %s, infoLabel = %s' % (info, infoLabels))
				item = (info, infoLabels)
				listItems.append(item)
				__addSingleItem(item, total)
				
		def __addSingleItem(itemTuple, total):
			item, extra = itemTuple
			self.addItem(info=item, extrainfo=extra, total_items=total)	

		self.__getFromCache(main, __parseAnimeSeries, __addSingleItem)

	def showEpisodes(self, main):
		def __showEpisodes(soup, listItems):
			episodes = soup.find('div', attrs={'id' : 'episodes'})
			if episodes is None:
				info={'Title': u"Pas d'episode trouve", 'mode' : PLAY_VIDEO_MODE }
				listItems.append(info)
				__addSingleItem(info, 1)
			else:
				episodesList = soup.find('div', attrs={'id' : 'episodes'}).findAll('a')
				total = len(episodesList)
				for episode in episodesList:
					title = episode.find('a', text=True)
					if title is None:
						continue
					title = title.strip()
					debug('checking %s' % title)
					vidHtml = downloadHTML(__site_url__ + episode['href'])
					soup = BeautifulSoup(vidHtml)
					jsWithVidLink = soup.find('div', attrs={'id':'lecteurFlash'}).find('script', attrs={'type':'text/javascript'}).find(text=True)
					m = re.search('url: \'(.+?)\',', jsWithVidLink)
					if m is None:
						total -= total
						continue
					else:
						link = m.group(1)
						debug(" titre = %s, link = %s" % (title, link))
						info = {'Title': title, 'mode' : PLAY_VIDEO_MODE, 'url': link }
						listItems.append(info)
						__addSingleItem(info, total)
		
		def __addSingleItem(item, total):
			self.addItem(info=item, isFolder=False, total_items=total)	
		
		self.__getFromCache(main, __showEpisodes, __addSingleItem)

	def mostViewed(self, main):
		self.showAnimeSeries(main)
		
	def promoted(self, main):
		self.showAnimeSeries(main)
	
	def endofdirectory(self, sortMethod='none'):
		# set sortmethod to something xbmc can use
		if sortMethod == 'title':
			xbmcplugin.addSortMethod(int(sys.argv[1]), xbmcplugin.SORT_METHOD_LABEL)
			xbmcplugin.addSortMethod(int(sys.argv[1]), xbmcplugin.SORT_METHOD_VIDEO_RATING)
		elif sortMethod == 'none':
			xbmcplugin.addSortMethod(int(sys.argv[1]), xbmcplugin.SORT_METHOD_NONE)

		dontAddToHierarchy = False
		xbmcplugin.endOfDirectory(handle=int(sys.argv[1]), updateListing=dontAddToHierarchy, cacheToDisc=True)
			
	def addItem(self, info, extrainfo=None, isFolder=True, total_items=0):
		#Defaults in dict. Use 'None' instead of None so it is compatible for quote_plus in parseArgs
		info.setdefault('url', 'None')
		info.setdefault('Thumb', 'None')
		info.setdefault('id', 'None')
		info.setdefault('category', 'None')
		info.setdefault('referer', 'None')
		info.setdefault('Icon', info['Thumb'])
		#create params for xbmcplugin module
		u = sys.argv[0] + \
			'?url=' + urllib.quote_plus(info['url']) + \
			'&mode=' + urllib.quote_plus(info['mode']) + \
			'&id=' + urllib.quote_plus(info['id']) + \
			'&category=' + urllib.quote_plus(info['category']) + \
			'&referer=' + urllib.quote_plus(info['referer']) + \
			'&icon=' + urllib.quote_plus(info['Thumb'])
		#create list item
		li = xbmcgui.ListItem(label=unescapeHTMLchar(info['Title']), iconImage=info['Thumb'], thumbnailImage=info['Thumb'])
		if extrainfo != None:
			li.setInfo(type="Video", infoLabels={ "Title":unescapeHTMLchar(extrainfo['name']), "Plot":unescapeHTMLchar(extrainfo['plot']), "Genre":unescapeHTMLchar(extrainfo['genre']), 'Rating':extrainfo['rating']})	
		#for videos, replace context menu with queue and add to favorites
		if not isFolder:
			li.setProperty("IsPlayable", "true")#let xbmc know this can be played, unlike a folder.
		#for folders, completely remove contextmenu, as it is totally useless.
		else:
			li.setProperty("IsPlayable", "false")
		#add item to list
		xbmcplugin.addDirectoryItem(handle=int(sys.argv[1]), url=u, listitem=li, isFolder=isFolder, totalItems=total_items)

	def playVideo(self, main):
		item = xbmcgui.ListItem(path=main.args.url)
		xbmcplugin.setResolvedUrl(handle=int(sys.argv[1]), succeeded=True, listitem=item)

class Main:

	args = None

	def __init__(self, checkMode=True):
		print sys.argv
		self.parseArgs()
		if checkMode:
			self.checkMode()

	def parseArgs(self):
		if (sys.argv[2]):
			argsDict = {}
			listParams = sys.argv[2][1:].split('&')
			debug('Parameter list: %s ' % str(listParams))
			for paramPair in listParams:
				key, value = paramPair.split('=')
				argsDict[str(key)] = str(value)
			self.args = UpdateArgs(argsDict)
		else:
			self.args = UpdateArgs({'mode': 'None', 'url': 'None', 'name' : 'None'})

	def checkMode(self):
		mode = self.args.mode
		if mode is None:
			UI().welcomePage()
		elif mode == CATEGORIE_LIST_MODE:
			UI().showCategories(self)
		elif mode == MOST_VIEWED_MODE:
			UI().mostViewed(self)
		elif mode == ANIME_LIST_MODE:
			UI().showAnimeSeries(self)
		elif mode == PROMOTED_LIST_MODE:
			UI().promoted(self)
		elif mode == SHOW_EPISODES_MODE:
			UI().showEpisodes(self)
		elif mode == PLAY_VIDEO_MODE:
			UI().playVideo(self)
		
